@@ -188,11 +188,11 @@ PKG: Dict[str, Dict[str, Any]] = {
         "apps": _exe_if_win(["chert"]),
         "apps_of_dependencies": _exe_if_win(["ashes", "markdown_py"]) + ["ashes.py"],
     },
-    "cloudtoken": {
-        "spec": "cloudtoken==2.1.0",
-        "apps": ["awstoken", "cloudtoken", "cloudtoken.app", "cloudtoken_proxy.sh"],
-        "apps_of_dependencies": _exe_if_win(["flask", "keyring", "normalizer"]) + ["jp.py"],
-    },
+    # "cloudtoken": {
+    #     "spec": "cloudtoken==2.1.0",
+    #     "apps": ["awstoken", "cloudtoken", "cloudtoken.app", "cloudtoken_proxy.sh"],
+    #     "apps_of_dependencies": _exe_if_win(["flask", "keyring", "normalizer"]) + ["jp.py"],
+    # },
     "coala": {
         "spec": "coala==0.11.0",
         "apps": _exe_if_win(["coala", "coala-ci", "coala-delete-orig", "coala-format", "coala-json"]),
