@@ -70,7 +70,7 @@ def test_install_easy_packages_globally(capsys, pipx_temp_env, caplog, package_n
 @pytest.mark.parametrize(
     "package_name, package_spec",
     [
-        ("cloudtoken", PKG["cloudtoken"]["spec"]),
+        # ("cloudtoken", PKG["cloudtoken"]["spec"]),
         ("awscli", PKG["awscli"]["spec"]),
         ("ansible", PKG["ansible"]["spec"]),
         ("shell-functools", PKG["shell-functools"]["spec"]),
@@ -85,11 +85,24 @@ def test_install_tricky_packages(capsys, pipx_temp_env, caplog, package_name, pa
     install_packages(capsys, pipx_temp_env, caplog, [package_spec], [package_name])
 
 
+def test_install_multiple_packages_when_some_already_installed(capsys, pipx_temp_env, caplog):
+    run_pipx_cli(["install", "black", "pycowsay"])
+    captured = capsys.readouterr()
+    assert "installed package black" in captured.out
+    assert "installed package pycowsay" in captured.out
+
+    run_pipx_cli(["install", "black", "pycowsay", "isort"])
+    captured = capsys.readouterr()
+    assert "'black' already seems to be installed" in captured.out
+    assert "'pycowsay' already seems to be installed" in captured.out
+    assert "installed package isort" in captured.out
+
+
 def test_install_tricky_multiple_packages(capsys, pipx_temp_env, caplog):
     if os.getenv("FAST"):
         pytest.skip("skipping slow tests")
 
-    packages = ["cloudtoken", "awscli", "shell-functools"]
+    packages = ["awscli", "shell-functools"]  # cloudtoken is temporarily removed
     package_specs = [PKG[package]["spec"] for package in packages]
 
     install_packages(capsys, pipx_temp_env, caplog, package_specs, packages)
@@ -149,6 +162,9 @@ def test_include_deps(pipx_temp_env, capsys):
     ],
 )
 def test_name_tricky_characters(caplog, capsys, pipx_temp_env, package_name, package_spec):
+    if sys.platform == "darwin" and package_name == "zest-releaser":
+        pytest.skip("Skipping zest-releaser due to missing Python 3.13 wheel for cmarkgfm on macOS")
+
     install_packages(capsys, pipx_temp_env, caplog, [package_spec], [package_name])
 
 
@@ -264,6 +280,39 @@ def test_pip_args_with_windows_path(pipx_temp_env, capsys):
     assert r"D:\\TEST\\DIR" in captured.err
 
 
+@pytest.mark.parametrize("constraint_flag", ["-c ", "--constraint ", "--constraint="])
+def test_pip_args_with_constraint_relative_path(constraint_flag, pipx_temp_env, tmp_path, caplog):
+    constraint_file_name = "constraints.txt"
+    package_name = "ipython"
+    package_version = "8.23.0"
+
+    os.chdir(tmp_path)
+    constraints_file = tmp_path / constraint_file_name
+    constraints_file.write_text(f"{package_name}!={package_version}")
+    constraints_file.touch()
+
+    assert not run_pipx_cli(["install", f"--pip-args='{constraint_flag}{constraint_file_name}'", package_name])
+
+    assert f"{constraint_flag}{constraints_file}" in caplog.text
+
+    subprocess_package_version = subprocess.run([package_name, "--version"], capture_output=True, text=True, check=False)
+    subprocess_package_version_output = subprocess_package_version.stdout.strip()
+    assert subprocess_package_version_output != package_version
+
+
+@pytest.mark.parametrize("constraint_flag", ["-c ", "--constraint ", "--constraint="])
+def test_pip_args_with_wrong_constraint_fail(constraint_flag, pipx_ultra_temp_env, tmp_path, capsys):
+    constraint_file_name = "constraints.txt"
+    os.chdir(tmp_path)
+
+    assert run_pipx_cli(["install", f"--pip-args='{constraint_flag}{constraint_file_name}'", "pycowsay"])
+
+    assert (
+        f"ERROR: Could not open requirements file: [Errno 2] No such file or directory: '{constraint_file_name}'"
+        in capsys.readouterr().err
+    )
+
+
 def test_install_suffix(pipx_temp_env, capsys):
     name = "pbr"
 
@@ -363,15 +412,15 @@ def test_passed_python_and_force_flag_warning(pipx_temp_env, capsys):
 
     assert not run_pipx_cli(["install", "black", "--force"])
     captured = capsys.readouterr()
-    assert (
-        "--python is ignored when --force is passed." not in captured.out
-    ), "Should only print warning if both flags present"
+    assert "--python is ignored when --force is passed." not in captured.out, (
+        "Should only print warning if both flags present"
+    )
 
     assert not run_pipx_cli(["install", "pycowsay", "--force"])
     captured = capsys.readouterr()
-    assert (
-        "--python is ignored when --force is passed." not in captured.out
-    ), "Should not print warning if package does not exist yet"
+    assert "--python is ignored when --force is passed." not in captured.out, (
+        "Should not print warning if package does not exist yet"
+    )
 
 
 @pytest.mark.parametrize(
