@@ -1,20 +1,24 @@
 import json
 import os
 import re
+import shutil
+import sys
 import time
 
-import pytest  # type: ignore
+import pytest  # type: ignore[import-not-found]
 
 from helpers import (
+    PIPX_METADATA_LEGACY_VERSIONS,
     app_name,
     assert_package_metadata,
     create_package_info_ref,
     mock_legacy_venv,
     remove_venv_interpreter,
     run_pipx_cli,
+    skip_if_windows,
 )
 from package_info import PKG
-from pipx import constants, shared_libs
+from pipx import constants, paths, shared_libs
 from pipx.pipx_metadata_file import PackageInfo, _json_decoder_object_hook
 
 
@@ -24,6 +28,17 @@ def test_cli(pipx_temp_env, monkeypatch, capsys):
     assert "nothing has been installed with pipx" in captured.err
 
 
+@skip_if_windows
+def test_cli_global(pipx_temp_env, monkeypatch, capsys):
+    assert not run_pipx_cli(["install", "pycowsay"])
+    captured = capsys.readouterr()
+    assert "installed package" in captured.out
+
+    assert not run_pipx_cli(["list", "--global"])
+    captured = capsys.readouterr()
+    assert "nothing has been installed with pipx" in captured.err
+
+
 def test_missing_interpreter(pipx_temp_env, monkeypatch, capsys):
     assert not run_pipx_cli(["install", "pycowsay"])
 
@@ -47,7 +62,7 @@ def test_list_suffix(pipx_temp_env, monkeypatch, capsys):
     assert f"package pycowsay 0.0.0.2 (pycowsay{suffix})," in captured.out
 
 
-@pytest.mark.parametrize("metadata_version", [None, "0.1", "0.2"])
+@pytest.mark.parametrize("metadata_version", PIPX_METADATA_LEGACY_VERSIONS)
 def test_list_legacy_venv(pipx_temp_env, monkeypatch, capsys, metadata_version):
     assert not run_pipx_cli(["install", "pycowsay"])
     mock_legacy_venv("pycowsay", metadata_version=metadata_version)
@@ -74,12 +89,12 @@ def test_list_suffix_legacy_venv(pipx_temp_env, monkeypatch, capsys, metadata_ve
 
 
 def test_list_json(pipx_temp_env, capsys):
-    pipx_venvs_dir = constants.PIPX_HOME / "venvs"
+    pipx_venvs_dir = paths.ctx.home / "venvs"
     venv_bin_dir = "Scripts" if constants.WINDOWS else "bin"
 
     assert not run_pipx_cli(["install", PKG["pycowsay"]["spec"]])
     assert not run_pipx_cli(["install", PKG["pylint"]["spec"]])
-    assert not run_pipx_cli(["inject", "pylint", PKG["isort"]["spec"]])
+    assert not run_pipx_cli(["inject", "pylint", PKG["black"]["spec"]])
     captured = capsys.readouterr()
 
     assert not run_pipx_cli(["list", "--json"])
@@ -104,19 +119,29 @@ def test_list_json(pipx_temp_env, capsys):
         "pylint",
         "pylint",
         pipx_venvs_dir,
-        **{"app_paths_of_dependencies": {"isort": [pipx_venvs_dir / "pylint" / venv_bin_dir / app_name("isort")]}},
+        **{
+            "app_paths_of_dependencies": {
+                "dill": [
+                    pipx_venvs_dir / "pylint" / venv_bin_dir / "get_gprof",
+                    pipx_venvs_dir / "pylint" / venv_bin_dir / "get_objgraph",
+                    pipx_venvs_dir / "pylint" / venv_bin_dir / "undill",
+                ],
+                "isort": [
+                    pipx_venvs_dir / "pylint" / venv_bin_dir / app_name("isort"),
+                    pipx_venvs_dir / "pylint" / venv_bin_dir / app_name("isort-identify-imports"),
+                ],
+            }
+        },
     )
     assert_package_metadata(
         PackageInfo(**json_parsed["venvs"]["pylint"]["metadata"]["main_package"]),
         pylint_package_ref,
     )
-    assert sorted(json_parsed["venvs"]["pylint"]["metadata"]["injected_packages"].keys()) == ["isort"]
-    isort_package_ref = create_package_info_ref("pylint", "isort", pipx_venvs_dir, include_apps=False)
-    print(isort_package_ref)
-    print(PackageInfo(**json_parsed["venvs"]["pylint"]["metadata"]["injected_packages"]["isort"]))
+    assert sorted(json_parsed["venvs"]["pylint"]["metadata"]["injected_packages"].keys()) == ["black"]
+    black_package_ref = create_package_info_ref("pylint", "black", pipx_venvs_dir, include_apps=False)
     assert_package_metadata(
-        PackageInfo(**json_parsed["venvs"]["pylint"]["metadata"]["injected_packages"]["isort"]),
-        isort_package_ref,
+        PackageInfo(**json_parsed["venvs"]["pylint"]["metadata"]["injected_packages"]["black"]),
+        black_package_ref,
     )
 
 
@@ -129,28 +154,93 @@ def test_list_short(pipx_temp_env, monkeypatch, capsys):
     captured = capsys.readouterr()
 
     assert "pycowsay 0.0.0.2" in captured.out
-    assert "pylint 2.3.1" in captured.out
+    assert "pylint 3.0.4" in captured.out
 
 
-def test_skip_maintenance(pipx_temp_env):
+def test_list_standalone_interpreter(pipx_temp_env, monkeypatch, mocked_github_api, capsys):
+    def which(name):
+        return None
+
+    monkeypatch.setattr(shutil, "which", which)
+
+    major = sys.version_info.major
+    minor = sys.version_info.minor
+    target_python = f"{major}.{minor}"
+
+    assert not run_pipx_cli(
+        [
+            "install",
+            "--fetch-missing-python",
+            "--python",
+            target_python,
+            PKG["pycowsay"]["spec"],
+        ]
+    )
+    captured = capsys.readouterr()
+
+    assert not run_pipx_cli(["list"])
+    captured = capsys.readouterr()
+
+    assert "standalone" in captured.out
+
+
+def test_list_does_not_trigger_maintenance(pipx_temp_env, caplog):
     assert not run_pipx_cli(["install", PKG["pycowsay"]["spec"]])
     assert not run_pipx_cli(["install", PKG["pylint"]["spec"]])
 
     now = time.time()
-    shared_libs.shared_libs.create(verbose=True)
+    shared_libs.shared_libs.create(verbose=True, pip_args=[])
     shared_libs.shared_libs.has_been_updated_this_run = False
 
     access_time = now  # this can be anything
-    os.utime(shared_libs.shared_libs.pip_path, (access_time, -shared_libs.SHARED_LIBS_MAX_AGE_SEC - 5 * 60 + now))
+    os.utime(
+        shared_libs.shared_libs.pip_path,
+        (access_time, -shared_libs.SHARED_LIBS_MAX_AGE_SEC - 5 * 60 + now),
+    )
     assert shared_libs.shared_libs.needs_upgrade
     run_pipx_cli(["list"])
-    assert shared_libs.shared_libs.has_been_updated_this_run
-    assert not shared_libs.shared_libs.needs_upgrade
+    assert not shared_libs.shared_libs.has_been_updated_this_run
+    assert shared_libs.shared_libs.needs_upgrade
 
-    os.utime(shared_libs.shared_libs.pip_path, (access_time, -shared_libs.SHARED_LIBS_MAX_AGE_SEC - 5 * 60 + now))
+    # same test with --skip-maintenance, which is a no-op
+    # we expect the same result, along with a warning
+    os.utime(
+        shared_libs.shared_libs.pip_path,
+        (access_time, -shared_libs.SHARED_LIBS_MAX_AGE_SEC - 5 * 60 + now),
+    )
     shared_libs.shared_libs.has_been_updated_this_run = False
     assert shared_libs.shared_libs.needs_upgrade
     run_pipx_cli(["list", "--skip-maintenance"])
-    shared_libs.shared_libs.skip_upgrade = False
     assert not shared_libs.shared_libs.has_been_updated_this_run
     assert shared_libs.shared_libs.needs_upgrade
+
+
+def test_list_pinned_packages(pipx_temp_env, monkeypatch, capsys):
+    assert not run_pipx_cli(["install", PKG["pycowsay"]["spec"]])
+    assert not run_pipx_cli(["install", PKG["black"]["spec"]])
+    captured = capsys.readouterr()
+
+    assert not run_pipx_cli(["pin", "black"])
+    assert not run_pipx_cli(["list", "--pinned"])
+
+    captured = capsys.readouterr()
+    assert "black 22.8.0" in captured.out
+    assert "pycowsay 0.0.0.2" not in captured.out
+
+
+def test_list_pinned_packages_include_injected(pipx_temp_env, monkeypatch, capsys):
+    assert not run_pipx_cli(["install", PKG["pylint"]["spec"], PKG["nox"]["spec"]])
+    assert not run_pipx_cli(["inject", "pylint", PKG["black"]["spec"]])
+
+    assert not run_pipx_cli(["pin", "pylint"])
+    assert not run_pipx_cli(["pin", "nox"])
+
+    captured = capsys.readouterr()
+
+    assert not run_pipx_cli(["list", "--pinned", "--include-injected"])
+
+    captured = capsys.readouterr()
+
+    assert "nox 2023.4.22" in captured.out
+    assert "pylint 3.0.4" in captured.out
+    assert "black 22.8.0 (injected in venv pylint)" in captured.out
