@@ -1,8 +1,9 @@
 import sys
 
-import pytest  # type: ignore
+import pytest  # type: ignore[import-not-found]
 
-from helpers import mock_legacy_venv, run_pipx_cli
+from helpers import PIPX_METADATA_LEGACY_VERSIONS, mock_legacy_venv, run_pipx_cli
+from pipx import shared_libs
 
 
 def test_reinstall_all(pipx_temp_env, capsys):
@@ -10,7 +11,13 @@ def test_reinstall_all(pipx_temp_env, capsys):
     assert not run_pipx_cli(["reinstall-all", "--python", sys.executable])
 
 
-@pytest.mark.parametrize("metadata_version", [None, "0.1", "0.2"])
+def test_reinstall_all_none(pipx_temp_env, capsys):
+    assert not run_pipx_cli(["reinstall-all"])
+    captured = capsys.readouterr()
+    assert "No packages reinstalled after running 'pipx reinstall-all'" in captured.out
+
+
+@pytest.mark.parametrize("metadata_version", PIPX_METADATA_LEGACY_VERSIONS)
 def test_reinstall_all_legacy_venv(pipx_temp_env, capsys, metadata_version):
     assert not run_pipx_cli(["install", "pycowsay"])
     mock_legacy_venv("pycowsay", metadata_version=metadata_version)
@@ -32,3 +39,13 @@ def test_reinstall_all_suffix_legacy_venv(pipx_temp_env, capsys, metadata_versio
     mock_legacy_venv(f"pycowsay{suffix}", metadata_version=metadata_version)
 
     assert not run_pipx_cli(["reinstall-all", "--python", sys.executable])
+
+
+def test_reinstall_all_triggers_shared_libs_upgrade(pipx_temp_env, caplog, capsys):
+    assert not run_pipx_cli(["install", "pycowsay"])
+
+    shared_libs.shared_libs.has_been_updated_this_run = False
+    caplog.clear()
+
+    assert not run_pipx_cli(["reinstall-all"])
+    assert "Upgrading shared libraries in" in caplog.text
