@@ -1,4 +1,4 @@
-from helpers import run_pipx_cli
+from helpers import run_pipx_cli, skip_if_windows
 from package_info import PKG
 
 
@@ -13,6 +13,18 @@ def test_uninject_simple(pipx_temp_env, capsys):
     assert "black" not in captured.out
 
 
+@skip_if_windows
+def test_uninject_simple_global(pipx_temp_env, capsys):
+    assert not run_pipx_cli(["install", "--global", "pycowsay"])
+    assert not run_pipx_cli(["inject", "--global", "pycowsay", PKG["black"]["spec"]])
+    assert not run_pipx_cli(["uninject", "--global", "pycowsay", "black"])
+    captured = capsys.readouterr()
+    assert "Uninjected package black" in captured.out
+    assert not run_pipx_cli(["list", "--global", "--include-injected"])
+    captured = capsys.readouterr()
+    assert "black" not in captured.out
+
+
 def test_uninject_with_include_apps(pipx_temp_env, capsys, caplog):
     assert not run_pipx_cli(["install", "pycowsay"])
     assert not run_pipx_cli(["inject", "pycowsay", PKG["black"]["spec"], "--include-deps", "--include-apps"])
