@@ -1,6 +1,6 @@
-import pytest  # type: ignore
+import pytest  # type: ignore[import-not-found]
 
-from helpers import mock_legacy_venv, run_pipx_cli
+from helpers import PIPX_METADATA_LEGACY_VERSIONS, mock_legacy_venv, run_pipx_cli
 
 
 def test_uninstall_all(pipx_temp_env, capsys):
@@ -8,7 +8,7 @@ def test_uninstall_all(pipx_temp_env, capsys):
     assert not run_pipx_cli(["uninstall-all"])
 
 
-@pytest.mark.parametrize("metadata_version", [None, "0.1", "0.2"])
+@pytest.mark.parametrize("metadata_version", PIPX_METADATA_LEGACY_VERSIONS)
 def test_uninstall_all_legacy_venv(pipx_temp_env, capsys, metadata_version):
     assert not run_pipx_cli(["install", "pycowsay"])
     mock_legacy_venv("pycowsay", metadata_version=metadata_version)
